searchData={"items":[{"type":"module","title":"Supabase","doc":"The main entrypoint for the Supabase SDK library.","ref":"Supabase.html"},{"type":"module","title":"Starting a Client - Supabase","doc":"You then can start a Client calling `Supabase.init_client/3`:\n\n    iex> Supabase.init_client(\"base_url\", \"api_key\", %{db: %{schema: \"public\"}})\n    {:ok, %Supabase.Client{}}","ref":"Supabase.html#module-starting-a-client"},{"type":"module","title":"Acknowledgements - Supabase","doc":"This package represents the base SDK for Supabase. That means\nthat it not includes all of the functionality of the Supabase client integrations, so you need to install each feature separetely, as:\n\n- [Auth/GoTrue](https://github.com/zoedsoupe/gotrue-ex)\n- [Storage](https://github.com/zoedsoupe/storage-ex)\n- [PostgREST](https://github.com/zoedsoupe/postgrest-ex)\n- `Realtime` - TODO\n- `UI` - TODO","ref":"Supabase.html#module-acknowledgements"},{"type":"module","title":"Supabase Storage - Supabase","doc":"Supabase Storage is a service for developers to store large objects like images, videos, and other files. It is a hosted object storage service, like AWS S3, but with a simple API and strong consistency.","ref":"Supabase.html#module-supabase-storage"},{"type":"module","title":"Supabase PostgREST - Supabase","doc":"PostgREST is a web server that turns your PostgreSQL database directly into a RESTful API. The structural constraints and permissions in the database determine the API endpoints and operations.","ref":"Supabase.html#module-supabase-postgrest"},{"type":"module","title":"Supabase Realtime - Supabase","doc":"Supabase Realtime provides a realtime websocket API powered by PostgreSQL notifications. It allows you to listen to changes in your database, and instantly receive updates as soon as they happen.","ref":"Supabase.html#module-supabase-realtime"},{"type":"module","title":"Supabase Auth/GoTrue - Supabase","doc":"Supabase Auth is a feature-complete user authentication system. It provides email & password sign in, email verification, password recovery, session management, and more, out of the box.","ref":"Supabase.html#module-supabase-auth-gotrue"},{"type":"module","title":"Supabase UI - Supabase","doc":"Supabase UI is a set of UI components that help you quickly build Supabase-powered applications. It is built on top of Tailwind CSS and Headless UI, and is fully customizable. The package provides `Phoenix.LiveView` components!","ref":"Supabase.html#module-supabase-ui"},{"type":"function","title":"Supabase.init_client/3","doc":"","ref":"Supabase.html#init_client/3"},{"type":"function","title":"Supabase.init_client!/3","doc":"","ref":"Supabase.html#init_client!/3"},{"type":"function","title":"Supabase.schema/0","doc":"","ref":"Supabase.html#schema/0"},{"type":"module","title":"Supabase.Client","doc":"A client for interacting with Supabase. This module is responsible for\nmanaging the connection options for your Supabase project.","ref":"Supabase.Client.html"},{"type":"module","title":"Usage - Supabase.Client","doc":"Generally, you can start a client by calling `Supabase.init_client/3`:\n\n    iex> base_url = \"https:// .supabase.io\"\n    iex> api_key = \" \"\n    iex> Supabase.init_client(base_url, api_key, %{})\n    {:ok, %Supabase.Client{}}\n\n> That way of initialisation is useful when you want to manage the connection options yourself or create one off clients.\n\nHowever, starting a client directly means you have to manage the connection options yourself. To make it easier, you can use the `Supabase.Client` module to manage the connection options for you.\n\nTo achieve this you can use the `Supabase.Client` module in your module:\n\n    defmodule MyApp.Supabase.Client do\n      use Supabase.Client\n    end\n\nThis will automatically start an Agent process to manage the connection options for you. But for that to work, you need to configure your defined Supabase client in your `config.exs`:\n\n    config :supabase_potion, MyApp.Supabase.Client,\n      base_url: \"https:// .supabase.co\",\n      api_key: \" \",\n      conn: %{access_token: \" \"}, # optional\n      db: %{schema: \"another\"}, # default to public\n      auth: %{debug: true} # optional\n\nAnother alternative would be to configure your Supabase Client at runtime, while starting your application:\n\n    defmodule MyApp.Application do\n      use Application\n\n      def start(_type, _args) do\n        children = [\n          {MyApp.Supabase.Client, [\n            base_url: \"https:// .supabase.co\",\n            api_key: \" \"\n          ]}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supabase.Client.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n    end\n\nFor more information on how to configure your Supabase Client with additional options, please refer to the [Supabase official documentation](https://supabase.com/docs/reference/javascript/initializing)","ref":"Supabase.Client.html#module-usage"},{"type":"module","title":"Examples - Supabase.Client","doc":"%Supabase.Client{\n      conn: %{\n        base_url: \"https:// .supabase.io\",\n        api_key: \" \",\n        access_token: \" \"\n      },\n      db: %Supabase.Client.Db{\n        schema: \"public\"\n      },\n      global: %Supabase.Client.Global{\n        headers: %{}\n      },\n      auth: %Supabase.Client.Auth{\n        auto_refresh_token: true,\n        debug: false,\n        detect_session_in_url: true,\n        flow_type: :implicit,\n        persist_session: true,\n        storage: nil,\n        storage_key: \"sb- -auth-token\"\n      }\n    }\n\n    iex> Supabase.Client.retrieve_connection(%Supabase.Client{})\n    %Supabase.Client.Conn{\n      base_url: \"https:// .supabase.io\",\n      api_key: \" \",\n      access_token: \" \"\n    }","ref":"Supabase.Client.html#module-examples"},{"type":"function","title":"Supabase.Client.parse/1","doc":"","ref":"Supabase.Client.html#parse/1"},{"type":"function","title":"Supabase.Client.parse!/1","doc":"","ref":"Supabase.Client.html#parse!/1"},{"type":"function","title":"Supabase.Client.retrieve_auth_url/2","doc":"Given a `Supabase.Client`, mounts the base url for the Auth/GoTrue feature.","ref":"Supabase.Client.html#retrieve_auth_url/2"},{"type":"function","title":"Examples - Supabase.Client.retrieve_auth_url/2","doc":"iex> Supabase.Client.retrieve_auth_url(%Supabase.Client{})\n    \"https:// .supabase.co/auth/v1\"","ref":"Supabase.Client.html#retrieve_auth_url/2-examples"},{"type":"function","title":"Supabase.Client.retrieve_base_url/1","doc":"Given a `Supabase.Client`, return the raw the base url for the Supabase project.","ref":"Supabase.Client.html#retrieve_base_url/1"},{"type":"function","title":"Examples - Supabase.Client.retrieve_base_url/1","doc":"iex> Supabase.Client.retrieve_base_url(%Supabase.Client{})\n    \"https:// .supabase.co\"","ref":"Supabase.Client.html#retrieve_base_url/1-examples"},{"type":"function","title":"Supabase.Client.retrieve_connection/1","doc":"Given a `Supabase.Client`, return the connection informations.","ref":"Supabase.Client.html#retrieve_connection/1"},{"type":"function","title":"Examples - Supabase.Client.retrieve_connection/1","doc":"iex> Supabase.Client.retrieve_connection(%Supabase.Client{})\n    %Supabase.Client.Conn{}","ref":"Supabase.Client.html#retrieve_connection/1-examples"},{"type":"function","title":"Supabase.Client.retrieve_storage_url/2","doc":"Given a `Supabase.Client`, mounts the base url for the Storage feature.","ref":"Supabase.Client.html#retrieve_storage_url/2"},{"type":"function","title":"Examples - Supabase.Client.retrieve_storage_url/2","doc":"iex> Supabase.Client.retrieve_storage_url(%Supabase.Client{})\n    \"https:// .supabase.co/storage/v1\"","ref":"Supabase.Client.html#retrieve_storage_url/2-examples"},{"type":"function","title":"Supabase.Client.update_access_token/2","doc":"","ref":"Supabase.Client.html#update_access_token/2"},{"type":"type","title":"Supabase.Client.params/0","doc":"","ref":"Supabase.Client.html#t:params/0"},{"type":"type","title":"Supabase.Client.t/0","doc":"","ref":"Supabase.Client.html#t:t/0"},{"type":"module","title":"Supabase.Client.Auth","doc":"Auth configuration schema. This schema is used to configure the auth\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Auth.html"},{"type":"module","title":"Fields - Supabase.Client.Auth","doc":"- `:auto_refresh_token` - Automatically refresh the token when it expires. Defaults to `true`.\n- `:debug` - Enable debug mode. Defaults to `false`.\n- `:detect_session_in_url` - Detect session in URL. Defaults to `true`.\n- `:flow_type` - Authentication flow type. Defaults to `\"implicit\"`.\n- `:persist_session` - Persist session. Defaults to `true`.\n- `:storage` - Storage type.\n- `:storage_key` - Storage key. Default to `\"sb-$host-auth-token\"` where $host is the hostname of your Supabase URL.\n\nFor more information about the auth options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[auth guides](https://supabase.com/docs/guides/auth)","ref":"Supabase.Client.Auth.html#module-fields"},{"type":"function","title":"Supabase.Client.Auth.changeset/3","doc":"","ref":"Supabase.Client.Auth.html#changeset/3"},{"type":"type","title":"Supabase.Client.Auth.params/0","doc":"","ref":"Supabase.Client.Auth.html#t:params/0"},{"type":"type","title":"Supabase.Client.Auth.t/0","doc":"","ref":"Supabase.Client.Auth.html#t:t/0"},{"type":"behaviour","title":"Supabase.Client.Conn","doc":"Conn configuration for Supabase Client. This schema is used to configure\nthe connection options. This schema is embedded in the `Supabase.Client`.","ref":"Supabase.Client.Conn.html"},{"type":"behaviour","title":"Fields - Supabase.Client.Conn","doc":"- `:base_url` - The Supabase Project URL to use. This option is required.\n- `:api_key` - The Supabase ProjectAPI Key to use. This option is required.\n- `:access_token` - The access token to use. Default to the API key.\n\nFor more information about the connection options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing).","ref":"Supabase.Client.Conn.html#module-fields"},{"type":"function","title":"Supabase.Client.Conn.changeset/2","doc":"","ref":"Supabase.Client.Conn.html#changeset/2"},{"type":"callback","title":"Supabase.Client.Conn.changeset/2","doc":"","ref":"Supabase.Client.Conn.html#c:changeset/2"},{"type":"callback","title":"Supabase.Client.Conn.parse/1","doc":"","ref":"Supabase.Client.Conn.html#c:parse/1"},{"type":"opaque","title":"Supabase.Client.Conn.changeset/0","doc":"","ref":"Supabase.Client.Conn.html#t:changeset/0"},{"type":"type","title":"Supabase.Client.Conn.params/0","doc":"","ref":"Supabase.Client.Conn.html#t:params/0"},{"type":"type","title":"Supabase.Client.Conn.t/0","doc":"","ref":"Supabase.Client.Conn.html#t:t/0"},{"type":"module","title":"Supabase.Client.Db","doc":"DB configuration schema. This schema is used to configure the database\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Db.html"},{"type":"module","title":"Fields - Supabase.Client.Db","doc":"- `:schema` - The default schema to use. Defaults to `\"public\"`.\n\nFor more information about the database options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[database guides](https://supabase.com/docs/guides/database).","ref":"Supabase.Client.Db.html#module-fields"},{"type":"function","title":"Supabase.Client.Db.changeset/2","doc":"","ref":"Supabase.Client.Db.html#changeset/2"},{"type":"type","title":"Supabase.Client.Db.params/0","doc":"","ref":"Supabase.Client.Db.html#t:params/0"},{"type":"type","title":"Supabase.Client.Db.t/0","doc":"","ref":"Supabase.Client.Db.html#t:t/0"},{"type":"module","title":"Supabase.Client.Global","doc":"Global configuration schema. This schema is used to configure the global\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Global.html"},{"type":"module","title":"Fields - Supabase.Client.Global","doc":"- `:headers` - The default headers to use in any Supabase request. Defaults to `%{}`.","ref":"Supabase.Client.Global.html#module-fields"},{"type":"function","title":"Supabase.Client.Global.changeset/2","doc":"","ref":"Supabase.Client.Global.html#changeset/2"},{"type":"type","title":"Supabase.Client.Global.params/0","doc":"","ref":"Supabase.Client.Global.html#t:params/0"},{"type":"type","title":"Supabase.Client.Global.t/0","doc":"","ref":"Supabase.Client.Global.html#t:t/0"},{"type":"module","title":"Supabase.Fetcher","doc":"A fundamental HTTP client for interfacing directly with Supabase services.\n\n`Supabase.Fetcher` provides the groundwork for sending HTTP requests to the Supabase infrastructure. This includes utilities for various HTTP methods such as GET, POST, PUT, DELETE, and functions to simplify the process of streaming data or uploading files.","ref":"Supabase.Fetcher.html"},{"type":"module","title":"Key Features - Supabase.Fetcher","doc":"- **Low-level HTTP Interactions**: This module allows for raw HTTP requests to any URL, simplifying interactions with web resources.\n- **Data Streaming**: Efficiently stream large data payloads, such as downloading files.\n- **Request Customization**: Extensive header customization and utility functions for constructing requests tailored to your requirements.\n- **Response Parsing**: Automatically converts JSON responses into Elixir maps and handles various response scenarios.","ref":"Supabase.Fetcher.html#module-key-features"},{"type":"module","title":"Recommended Usage - Supabase.Fetcher","doc":"While `Supabase.Fetcher` is versatile and comprehensive, it operates at a very granular level. For most applications and needs, leveraging higher-level APIs that correspond to specific Supabase services is advisable:\n\n- `Supabase.Storage` - API to interact directly with buckets and objects in Supabase Storage.","ref":"Supabase.Fetcher.html#module-recommended-usage"},{"type":"module","title":"Disclaimer - Supabase.Fetcher","doc":"If your aim is to directly harness this module as a low-level HTTP client, due to missing features in other packages or a desire to craft a unique Supabase integration, you can certainly do so. However, always keep in mind that `Supabase.Storage` and other Supabase-oriented packages might offer better abstractions and ease-of-use.\n\nUse `Supabase.Fetcher` with a clear understanding of its features and operations.","ref":"Supabase.Fetcher.html#module-disclaimer"},{"type":"function","title":"Supabase.Fetcher.apply_client_headers/3","doc":"","ref":"Supabase.Fetcher.html#apply_client_headers/3"},{"type":"function","title":"Supabase.Fetcher.apply_headers/3","doc":"Convenience function that given a `apikey` and a optional ` token`, it will return the headers\nto be used in a request to your Supabase API.","ref":"Supabase.Fetcher.html#apply_headers/3"},{"type":"function","title":"Examples - Supabase.Fetcher.apply_headers/3","doc":"iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer apikey-value\"}]\n\n     iex> Supabase.Fetcher.apply_conn_headers(\"apikey-value\", \"token-value\")\n     [{\"apikey\", \"apikey-value\"}, {\"authorization\", \"Bearer token-value\"}]","ref":"Supabase.Fetcher.html#apply_headers/3-examples"},{"type":"function","title":"Supabase.Fetcher.delete/4","doc":"Simple DELETE request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#delete/4"},{"type":"function","title":"Examples - Supabase.Fetcher.delete/4","doc":"iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}\n\n     iex> Supabase.Fetcher.delete(\"https://example.com\", %{key: \"value\"})\n     {:error, :not_found}","ref":"Supabase.Fetcher.html#delete/4-examples"},{"type":"function","title":"Supabase.Fetcher.format_response/1","doc":"","ref":"Supabase.Fetcher.html#format_response/1"},{"type":"function","title":"Supabase.Fetcher.get/1","doc":"Simple GET request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#get/1"},{"type":"function","title":"Examples - Supabase.Fetcher.get/1","doc":"iex> Supabase.Fetcher.get(\"https://example.com\")\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#get/1-examples"},{"type":"function","title":"Supabase.Fetcher.get/2","doc":"","ref":"Supabase.Fetcher.html#get/2"},{"type":"function","title":"Supabase.Fetcher.get/3","doc":"","ref":"Supabase.Fetcher.html#get/3"},{"type":"function","title":"Supabase.Fetcher.get_full_url/2","doc":"","ref":"Supabase.Fetcher.html#get_full_url/2"},{"type":"function","title":"Supabase.Fetcher.get_header/2","doc":"","ref":"Supabase.Fetcher.html#get_header/2"},{"type":"function","title":"Supabase.Fetcher.get_header/3","doc":"","ref":"Supabase.Fetcher.html#get_header/3"},{"type":"function","title":"Supabase.Fetcher.head/4","doc":"Simple HEAD request that format the response to a map or\nretrieve the error as `String.t()`","ref":"Supabase.Fetcher.html#head/4"},{"type":"function","title":"Supabase.Fetcher.new_connection/4","doc":"","ref":"Supabase.Fetcher.html#new_connection/4"},{"type":"function","title":"Supabase.Fetcher.patch/4","doc":"Simple PATCH request that format the response to a map or\nretrieve the error as `String.t()`","ref":"Supabase.Fetcher.html#patch/4"},{"type":"function","title":"Supabase.Fetcher.post/4","doc":"Simple POST request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#post/4"},{"type":"function","title":"Examples - Supabase.Fetcher.post/4","doc":"iex> Supabase.Fetcher.post(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#post/4-examples"},{"type":"function","title":"Supabase.Fetcher.put/4","doc":"Simple PUT request that format the response to a map or retrieve\nthe error reason as `String.t()`.","ref":"Supabase.Fetcher.html#put/4"},{"type":"function","title":"Examples - Supabase.Fetcher.put/4","doc":"iex> Supabase.Fetcher.put(\"https://example.com\", %{key: \"value\"})\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#put/4-examples"},{"type":"function","title":"Supabase.Fetcher.stream/3","doc":"Makes a HTTP request to the desired URL, with default headers and\nstream back the response. Good to stream large files downlaods.\n\nYou can also pass custom `Finch` options directly to the underlying `Finch.stream/4` function.\nThose options can be seen on the [Finch documentation](https://hexdocs.pm/finch/Finch.html#stream/5-options).","ref":"Supabase.Fetcher.html#stream/3"},{"type":"function","title":"Examples - Supabase.Fetcher.stream/3","doc":"iex> {status, stream} = Supabase.Fetcher.stream(\"https://example.com\")\n     iex> file = File.stream!(\"path/to/file\", [], 4096)\n     Stream.run Stream.into(stream, file)","ref":"Supabase.Fetcher.html#stream/3-examples"},{"type":"function","title":"Supabase.Fetcher.upload/4","doc":"Upload a binary to the desired URL.\n\nparams:\n- `method`: `:put` or `:post`\n- `url`: the URL to upload the file\n- `file`: the path to the file to upload\n- `headers`: list of additional headers to append to the request","ref":"Supabase.Fetcher.html#upload/4"},{"type":"function","title":"Examples - Supabase.Fetcher.upload/4","doc":"iex> Supabase.Fetcher.upload(:post, \"https://example.com\", \"path/to/file\")\n     {:ok, %{\"key\" => \"value\"}}","ref":"Supabase.Fetcher.html#upload/4-examples"},{"type":"function","title":"Supabase.Fetcher.version/0","doc":"","ref":"Supabase.Fetcher.html#version/0"},{"type":"behaviour","title":"Supabase.FetcherBehaviour","doc":"Defines Supabase HTTP Clients callbacks","ref":"Supabase.FetcherBehaviour.html"},{"type":"callback","title":"Supabase.FetcherBehaviour.delete/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:delete/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.get/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:get/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.head/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:head/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.patch/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:patch/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.post/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:post/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.put/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:put/4"},{"type":"callback","title":"Supabase.FetcherBehaviour.stream/3","doc":"","ref":"Supabase.FetcherBehaviour.html#c:stream/3"},{"type":"callback","title":"Supabase.FetcherBehaviour.upload/4","doc":"","ref":"Supabase.FetcherBehaviour.html#c:upload/4"},{"type":"type","title":"Supabase.FetcherBehaviour.body/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:body/0"},{"type":"type","title":"Supabase.FetcherBehaviour.headers/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:headers/0"},{"type":"type","title":"Supabase.FetcherBehaviour.method/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:method/0"},{"type":"type","title":"Supabase.FetcherBehaviour.opts/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:opts/0"},{"type":"type","title":"Supabase.FetcherBehaviour.reason/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:reason/0"},{"type":"type","title":"Supabase.FetcherBehaviour.response/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:response/0"},{"type":"type","title":"Supabase.FetcherBehaviour.result/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:result/0"},{"type":"type","title":"Supabase.FetcherBehaviour.url/0","doc":"","ref":"Supabase.FetcherBehaviour.html#t:url/0"},{"type":"exception","title":"Supabase.MissingSupabaseConfig","doc":"","ref":"Supabase.MissingSupabaseConfig.html"},{"type":"extras","title":"Supabase Potion","doc":"# Supabase Potion\n\nWhere the magic starts!\n\n> [!WARNING]\n> This project is still in high development, expect breaking changes.","ref":"readme.html"},{"type":"extras","title":"Getting Started - Supabase Potion","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"Installation - Supabase Potion","doc":"To install the base SDK:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.5\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"General installation - Supabase Potion","doc":"This library per si is the base foundation to user Supabase services from Elixir, so to integrate with specific services you need to add each client library you want to use.\n\nAvailable client services are:\n- [PostgREST](https://github.com/zoedsoupe/postgres-ex)\n- [Storage](https://github.com/zoedsoupe/storage-ex)\n- [Auth/GoTrue](https://github.com/zoedsoupe/gotrue-ex)\n\nSo if you wanna use the Storage and Auth/GoTrue services, your `mix.exs` should look like that:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.5\"}, # base SDK\n    {:supabase_storage, \"~> 0.3\"}, # storage integration\n    {:supabase_gotrue, \"~> 0.3\"}, # auth integration\n  ]\nend\n```","ref":"readme.html#general-installation"},{"type":"extras","title":"General usage - Supabase Potion","doc":"This library per si is the base foundation to user Supabase services from Elixir, so to integrate with specific services you need to add each client library you want to use.\n\nAvailable client services are:\n- [PostgREST](https://github.com/zoedsoupe/postgres-ex)\n- [Storage](https://github.com/zoedsoupe/storage-ex)\n- [Auth/GoTrue](https://github.com/zoedsoupe/gotrue-ex)\n\nSo if you wanna use the Storage and Auth/GoTrue services, your `mix.exs` should look like that:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.4\"}, # base SDK\n    {:supabase_storage, \"~> 0.3\"}, # storage integration\n    {:supabase_gotrue, \"~> 0.3\"}, # auth integration\n  ]\nend\n```","ref":"readme.html#general-usage"},{"type":"extras","title":"Clients - Supabase Potion","doc":"A `Supabase.Client` holds general information about Supabase, that can be used to intereact with any of the children integrations, for example: `Supabase.Storage` or `Supabase.UI`.\n\n`Supabase.Client` is defined as:\n\n- `:conn` - connection information, the only required option as it is vital to the `Supabase.Client`.\n    - `:base_url` - The base url of the Supabase API, it is usually in the form `https:// .supabase.io`.\n    - `:api_key` - The API key used to authenticate requests to the Supabase API.\n    - `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `:db` - default database options\n    - `:schema` - default schema to use, defaults to `\"public\"`\n- `:global` - global options config\n    - `:headers` - additional headers to use on each request\n- `:auth` - authentication options\n    - `:auto_refresh_token` - automatically refresh the token when it expires, defaults to `true`\n    - `:debug` - enable debug mode, defaults to `false`\n    - `:detect_session_in_url` - detect session in URL, defaults to `true`\n    - `:flow_type` - authentication flow type, defaults to `\"web\"`\n    - `:persist_session` - persist session, defaults to `true`\n    - `:storage` - storage type\n    - `:storage_key` - storage key","ref":"readme.html#clients"},{"type":"extras","title":"Usage - Supabase Potion","doc":"There are two ways to create a `Supabase.Client`:\n1. one off clients\n2. self managed clients\n\n#### One off clients\n\nOne off clients are clients that are created and managed by your application. They are useful for quick interactions with the Supabase API.\n\n```elixir\niex> Supabase.init_client(\"https:// \", \" \")\niex> {:ok, %Supabase.Client{}}\n```\n\nAny additional config can be passed as the third argument:\n\n```elixir\niex> Supabase.init_client(\"https:// \", \" \", %{db: %{schema: \"another\"}}})\niex> {:ok, %Supabase.Client{}}\n```\n\nFor more information on the available options, see the [Supabase.Client](https://hexdocs.pm/supabase_potion/Supabase.Client.html) module documentation.\n\n> There's also a bang version of `Supabase.init_client/3` that will raise an error if the client can't be created.\n\n#### Self managed clients\n\nSelf managed clients are clients that are created and managed by a separate process on your application. They are useful for long running applications that need to interact with the Supabase API.\n\nIf you don't have experience with processes or is a Elixir begginner, you should take a deep look into the Elixir official getting started section about processes, concurrency and distribution before to proceed.\n- [Processes](https://hexdocs.pm/elixir/processes.html)\n- [Agent getting started](https://hexdocs.pm/elixir/agents.html)\n- [GenServer getting started](https://hexdocs.pm/elixir/genservers.html)\n- [Supervison trees getting started](https://hexdocs.pm/elixir/supervisor-and-application.html)\n\nSo, to define a self managed client, you need to define a module that will hold the client state and the client process.\n\n```elixir\ndefmodule MyApp.Supabase.Client do\n  use Supabase.Client\nend\n```\n\nFor that to work, you also need to configure the client in your `config.exs`:\n\n```elixir\nimport Config\n\nconfig :supabase_potion, MyApp.Supabase.Client,\n  base_url: \"https:// \", # required\n  api_key: \" \", # required\n  conn: %{access_token: \" \"}, # optional\n  db: %{schema: \"another\"} # additional options\n```\n\nThen, you can start the client process in your application supervision tree:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      MyApp.Supabase.Client\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nNow you can interact with the client process:\n\n```elixir\niex> {:ok, %Supabase.Client{} = client} = MyApp.Supabase.Client.get_client()\niex> Supabase.GoTrue.sign_in_with_password(client, email: \"\", password: \"\")\n```\n\nFor more examples on how to use the client, check clients implementations docs:\n- [Supabase.GoTrue](https://hexdocs.pm/supabase_go_true)\n- [Supabase.Storage](https://hexdocs.pm/supabase_storage)\n- [Supabase.PostgREST](https://hexdocs.pm/supabase_postgrest)","ref":"readme.html#usage"},{"type":"extras","title":"How to find my Supabase base URL? - Supabase Potion","doc":"You can find your Supabase base URL in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe base URL is the first field on the page.","ref":"readme.html#how-to-find-my-supabase-base-url"},{"type":"extras","title":"How to find my Supabase API Key? - Supabase Potion","doc":"You can find your Supabase API key in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe API key is the second field on the page.\n\nThere two types of API keys, the public and the private. The last one\nbypass any Row Level Security (RLS) rules you have set up.\nSo you shouldn't use it in your frontend application.\n\nIf you don't know what RLS is, you can read more about it here:\nhttps://supabase.com/docs/guides/auth/row-level-security\n\nFor most cases you should prefer to use the public \"anon\" Key.","ref":"readme.html#how-to-find-my-supabase-api-key"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}